@@ -4,7 +4,7 @@ from django.conf import settings
 
 from urlauth.util import load_key, InvalidKey
 from urlauth.models import AuthKey
-from urlauth.signals import key_processed, key_loaded
+from urlauth.signals import key_loaded, key_user_found
 
 
 class AuthKeyMiddleware(object):
@@ -28,12 +28,12 @@ class AuthKeyMiddleware(object):
         except User.DoesNotExist:
             pass
         else:
+            key_user_found.send(sender=AuthKey, key=key, user=user, request=request)
+
             if user.is_active:
                 user.backend = 'django.contrib.auth.backends.ModelBackend'
                 auth.login(request, user)    
 
-            key_processed.send(sender=AuthKey, key=key, request=request)
-
         if key.onetime:
             key.delete()
         else:
